/******************************************************************************
 * $Header: /CommonBe/agmsmith/Programming/ScriptOCron/RCS/URLConverter.h,v 1.1 2015/11/25 00:35:07 agmsmith Exp $
 *
 * This utility class converts URL strings into the separate elements of a URL,
 * and back.
 *
 * The most complex URL this library handles looks like:
 * ftp://user:password@address:port/path/filename
 *
 * The individual components of the URL are exposed as separate string values
 * for the library user to manipulate.  Odd characters in a component get
 * escaped when converted to the URL form (like "@" in the password, often used
 * for anonymous FTP logins, which would otherwise conflict with the "@" in the
 * URL).  Components that are at default values (like port 80 for HTTP) aren't
 * included in the URL form.
 *
 * This URLConverter software is licensed under the MIT license.
 *
 * Copyright (c) 2015 by Alexander G. M. Smith.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to
 * deal in the Software without restriction, including without limitation the
 * rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
 * sell copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 */

/******************************************************************************
 * The main class for storing a URL and converting it to or from the component
 * strings.
 */

class URLConverter
{
public: // Public types.
  enum URLElementTypeEnum
  {
    UET_PROTOCOL = 0,
    UET_USERNAME,
    UET_PASSWORD,
    UET_ADDRESS,
    UET_PORT,
    UET_PATH,
    UET_FILENAME,
    UET_NUMBER_OF_ELEMENTS
  };

public: // Constructor and destructor.
  URLConverter ();

public: // Member functions.
  void ClearAll ();

  const char *GetValue (URLElementTypeEnum Element);
  void SetValue (URLElementTypeEnum Element, const char *NewString);

  void FromString (const char *Buffer);
    /* Convert a URL string into the component parts. */

  void ToString (BString &OutputString);
    /* Converts the components into a URL string.  Components that are missing
    are set to empty strings. */

private: // Member variables.
  BString m_Elements[UET_NUMBER_OF_ELEMENTS]; // BeOS string class for storage.
};



#if TEST_URL_CONVERTER
/******************************************************************************
 * Stuff for testing this class, normally not compiled.
 */

void TestURLConverter ();
#endif


/******************************************************************************
 * $Log: URLConverter.h,v $
 * Revision 1.1  2015/11/25 00:35:07  agmsmith
 * Initial revision
 *
 */
